==> ismah-3.0.1%2B1.19.4%2Bfabric-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final class_2960 TEXTURE = /*? >=1.21 {*/ /*ResourceLocation.parse *//*?} else {*/ new class_2960 /*?}*/("textures/entity/lead_knot.png");

    private static final class_630 RIGHT_LEASH = buildModel(
            "leads$right_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 LEFT_LEASH = buildModel(
            "leads$left_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static class_630 buildModel(String name, class_5606 builder) {
        class_5609 modelData = new class_5609();
        class_5610 modelPartData = modelData.method_32111();
        modelPartData.method_32117(name, builder, class_5603.method_32090(-5.0F, 2.0F, 0.0F));
        return class_5607.method_32110(modelData, 32, 32).method_32109();
    }

    public static void renderRightArmLeash(class_4587 matrices, class_4597 vertices, int light,
                                           //? if <=1.21.1 {
                                           net.minecraft.class_591<net.minecraft.class_742> model
                                           /*?} else {*/
                                           /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           *///?}
    ) {
        class_630 leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.field_3401, leash);
    }

    public static void renderLeftArmLeash(class_4587 matrices, class_4597 vertices, int light,
                                          //? if <=1.21.1 {
                                          net.minecraft.class_591<net.minecraft.class_742> model
                                          /*?} else {*/
                                          /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          *///?}
    ) {
        class_630 leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.field_27433, leash);
    }

    public static void renderArmLeash(class_4587 matrices, class_4597 vertices, int light, class_630 arm, class_630 leash) {
        leash.field_3657 = arm.field_3657;
        leash.field_3656 = arm.field_3656;
        leash.field_3655 = arm.field_3655;
        leash.field_3654 = arm.field_3654;
        leash.field_3675 = arm.field_3675;
        leash.field_3674 = arm.field_3674;
        leash.field_37938 = arm.field_37938;
        leash.field_37939 = arm.field_37939;
        leash.field_37940 = arm.field_37940;

        leash.method_22698(matrices, vertices.getBuffer(class_1921.method_23572(TEXTURE)), light, class_4608.field_21444);
    }
}

==> ismah-3.0.2%2B1.21%2Bfabric-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final class_2960 TEXTURE = /*? >=1.21 {*/ class_2960.method_60654 /*?} else {*/ /*new ResourceLocation *//*?}*/("textures/entity/lead_knot.png");

    private static final class_630 RIGHT_LEASH = buildModel(
            "leads$right_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 LEFT_LEASH = buildModel(
            "leads$left_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static final class_630 LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            class_5606.method_32108().method_32101(0, 0).method_32098(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new class_5605(0.0F))
    );

    private static class_630 buildModel(String name, class_5606 builder) {
        class_5609 modelData = new class_5609();
        class_5610 modelPartData = modelData.method_32111();
        modelPartData.method_32117(name, builder, class_5603.method_32090(-5.0F, 2.0F, 0.0F));
        return class_5607.method_32110(modelData, 32, 32).method_32109();
    }

    public static void renderRightArmLeash(class_4587 matrices, class_4597 vertices, int light,
                                           //? if <=1.21.1 {
                                           net.minecraft.class_591<net.minecraft.class_742> model
                                           /*?} else {*/
                                           /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           *///?}
    ) {
        class_630 leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.field_3401, leash);
    }

    public static void renderLeftArmLeash(class_4587 matrices, class_4597 vertices, int light,
                                          //? if <=1.21.1 {
                                          net.minecraft.class_591<net.minecraft.class_742> model
                                          /*?} else {*/
                                          /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          *///?}
    ) {
        class_630 leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.field_27433, leash);
    }

    public static void renderArmLeash(class_4587 matrices, class_4597 vertices, int light, class_630 arm, class_630 leash) {
        leash.field_3657 = arm.field_3657;
        leash.field_3656 = arm.field_3656;
        leash.field_3655 = arm.field_3655;
        leash.field_3654 = arm.field_3654;
        leash.field_3675 = arm.field_3675;
        leash.field_3674 = arm.field_3674;
        leash.field_37938 = arm.field_37938;
        leash.field_37939 = arm.field_37939;
        leash.field_37940 = arm.field_37940;

        leash.method_22698(matrices, vertices.getBuffer(class_1921.method_23572(TEXTURE)), light, class_4608.field_21444);
    }
}
